summaryrefslogtreecommitdiff
path: root/src/testing/testing_api_cmd_post_instances.c
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2020-04-24 01:23:35 +0200
committerChristian Grothoff <christian@grothoff.org>2020-04-24 01:23:35 +0200
commit0b57eac8f3b99941a11f11f35feac1926cd21d31 (patch)
tree1e3cb7efa7c60ab8f85e0797979adc7f23dda086 /src/testing/testing_api_cmd_post_instances.c
parentb378eea34812a9b561be6149e40c4518070f34f7 (diff)
downloadmerchant-0b57eac8f3b99941a11f11f35feac1926cd21d31.tar.gz
merchant-0b57eac8f3b99941a11f11f35feac1926cd21d31.tar.bz2
merchant-0b57eac8f3b99941a11f11f35feac1926cd21d31.zip
implement purge
Diffstat (limited to 'src/testing/testing_api_cmd_post_instances.c')
-rw-r--r--src/testing/testing_api_cmd_post_instances.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/testing/testing_api_cmd_post_instances.c b/src/testing/testing_api_cmd_post_instances.c
index b50162b8..f9da2dae 100644
--- a/src/testing/testing_api_cmd_post_instances.c
+++ b/src/testing/testing_api_cmd_post_instances.c
@@ -35,7 +35,7 @@ struct PostInstancesState
{
/**
* Handle for a "GET instance" request.
*/
struct TALER_MERCHANT_InstancesPostHandle *iph;
@@ -50,7 +50,7 @@ struct PostInstancesState
const char *merchant_url;
/**
* ID of the instance to run GET for.
*/
const char *instance_id;
@@ -183,7 +183,7 @@ post_instances_run (void *cls,
/**
* Free the state of a "GET instance" CMD, and possibly
* cancel a pending operation thereof.
*
* @param cls closure.
@@ -198,7 +198,7 @@ post_instances_cleanup (void *cls,
if (NULL != pis->iph)
{
GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
- "GET /instances/$ID operation did not complete\n");
+ "POST /instances operation did not complete\n");
TALER_MERCHANT_instances_post_cancel (pis->iph);
}
json_decref (pis->address);
@@ -35,7 +35,7 @@ struct PostInstancesState
{
/**
- * Handle for a "GET instance" request.
+ * Handle for a "POST instance" request.
*/
struct TALER_MERCHANT_InstancesPostHandle *iph;
@@ -50,7 +50,7 @@ struct PostInstancesState
const char *merchant_url;
/**
- * ID of the instance to run GET for.
+ * ID of the instance to run POST for.
*/
const char *instance_id;
@@ -183,7 +183,7 @@ post_instances_run (void *cls,
/**
- * Free the state of a "GET instance" CMD, and possibly
+ * Free the state of a "POST /instances" CMD, and possibly
* cancel a pending operation thereof.
*